Perf analysis report

PERF analysis report PERF

Summary
class="ui sortable celled table"
Genome Info
Homo sapiens.fna
File Name
3.24Gb
Genome size
45.4
GC%
545
Sequences
Repeat Info
4,631,324
Total repeats
69.09 Mb
Repeat bases
2.15 %
Percent genome covered
501/501
Repeat classes
1428
Frequency per Mb
21467
Base density per Mb
Options
Show
Order
Data:
Bases
Frequency
Options
Kmer grouping
Select Repeats:
Data:
Bases
Frequency
Options
to
length
range
Options
Group
Options
Bin size:
Bin size